import request from '@/utils/request' 
import Qs from 'qs'

export function talentList(query) {
  return request({
    url: '/kstalent/talentList',
    method: 'get',
    params: query
  })
}
export function talentDownload(query) {
    return request({
      url: '/kstalent/talentList',
      method: 'get',
      params: query,
      responseType: 'blob'
    })
  }

export function addNewTalent(data) {
  return request({
      url: '/kstalent/addNewTalent',
      method: 'post',
      data
  })
} 
export function createCommonPlan(data) {
  return request({
      url: '/dyplan/createCommonPlan',
      method: 'post',
      data
  })
} 
export function cancelPlanTalent(query) {
  return request({
    url: '/kstalent/cancelPlanTalent',
    method: 'get',
    params: query
  })
}

export function updateTalent(data) {
  return request({
    url: '/kstalent/updateTalent',
    method: 'post',
    data
  })
}
 
export function importTalent(data, config) {
  return request({
    url: '/kstalent/batchAdd',
    method: 'post',
    config: config,
    data
  })
} 

export function deleteTalentList(data){
  return request({
    url: '/kstalent/delete',
    method: 'post',
    data
})
} 